package com.composition.android.ad.admob.load.request

import android.content.Context
import com.composition.android.lib.ad.AdManager
import com.composition.android.lib.ad.basic.AdLoadCode
import com.composition.android.lib.ad.basic.AdResult
import com.composition.android.lib.ad.bean.AdUnitBean
import com.composition.android.lib.ad.interfaces.IAdFormatRequest
import com.composition.android.lib.ad.util.adLogE
import com.google.android.gms.ads.AdListener
import com.google.android.gms.ads.AdView
import com.google.android.gms.ads.LoadAdError
import com.composition.android.ad.admob.bean.AdmobAdUnitBean
import com.composition.android.ad.admob.util.getAdSize
import com.composition.android.ad.admob.util.printAdInfo
import kotlinx.coroutines.suspendCancellableCoroutine
import kotlin.coroutines.resume

/**
 * @classname:
 * @auther: LiuXiaoLong
 * @date: 2022/9/5
 * description:Admob横幅广告加载实现
 */
class AdmobBannerRequestImpl : IAdFormatRequest {


    override suspend fun load(context: Context, adUnitBean: AdUnitBean): AdResult {
        return suspendCancellableCoroutine<AdResult> {
            val adView = AdView(context).apply {
                adUnitId = adUnitBean.adUnitId
                setAdSize(if (adUnitBean is AdmobAdUnitBean){
                    adUnitBean.adSize
                }else{
                    getAdSize(context)
                })
            }

            val listener: AdListener = object : AdListener() {
                override fun onAdLoaded() {
                    super.onAdLoaded()
                    printAdInfo(adUnitBean, adView.responseInfo)
                    it.resume(
                        AdResult.Success(
                            adView,
                            adUnitBean,
                            AdLoadCode.SUCCESS,
                            "AdMob横幅广告加载成功"
                        )
                    )
                }

                override fun onAdFailedToLoad(p0: LoadAdError) {
                    super.onAdFailedToLoad(p0)
                    adLogE(AdManager.TAG, p0.message)
                    it.resume(
                        AdResult.Fail(
                            adUnitBean,
                            AdLoadCode.FAIL,
                            p0.message
                        )
                    )
                }
            }

            adView.adListener = listener
            val adRequest = com.google.android.gms.ads.AdRequest.Builder()
                .build()
            adView.loadAd(adRequest)
        }
    }
}